@@ -249,9 +249,11 @@ public interface MailContentType extends ContentType {
      * @param folderId
      * @param session
      * @param requestedFields
+     * @param firstMatch
+     * @param lastMatch
      * @return
      */
-    public List<DataObject> searchMails(JSONObject searchCriteria, String folderId, Session session, BitSet requestedFields) throws USMException;
+    public List<DataObject> searchMails(JSONObject searchCriteria, String folderId, Session session, BitSet requestedFields, int firstMatch, int lastMatch) throws USMException;
 
     /**
      * Search mail folder for the given free text.
@@ -260,10 +262,12 @@ public interface MailContentType extends ContentType {
      * @param folderId
      * @param session
      * @param requestedFields
+     * @param firstMatch
+     * @param lastMatch
      * @return
      * @throws USMException
      */
-    public List<DataObject> searchMails(String searchText, String folderId, Session session, BitSet requestedFields) throws USMException;
+    public List<DataObject> searchMails(String searchText, String folderId, Session session, BitSet requestedFields, int firstMatch, int lastMatch) throws USMException;
 
     /**
      * Gets the vacation rule for this session.
