@@ -127,4 +127,11 @@ public interface SessionManager extends OXEventListener {
 	 * @param protocol
 	 */
 	void disableWaitForChanges(String protocol);
+
+	/**
+	 * This method removes the given session from the cache.
+	 * 
+	 * @param session
+	 */
+    void removeSession(Session session);
 }
