@@ -293,10 +293,16 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
         if (contentTypes == null)
             return parameters;
         StringBuilder sb = new StringBuilder(128);
+        boolean needsComma = false;
         for (ContentType contentType : contentTypes) {
             if (contentType.canBeFolderElementsContentType()) {
+                if (needsComma) {
+                    sb.append(',');
+                }
+                else {
+                    needsComma = true;
+                }
                 sb.append(contentType.getID());
-                sb.append(',');
             }
         }
         parameters.put(ALLOWED_MODULES, sb.toString());
