@@ -191,7 +191,9 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         JSONObject requestBody = new JSONObject();
         try {
             requestBody.put("confirmation", response);
-            requestBody.put("confirmmessage", confirmMessage);
+            if (!confirmMessage.isEmpty()) {
+                requestBody.put("confirmmessage", confirmMessage);
+            }
             requestBody.put(CommonConstants.ID, computeFolderOwnerID(object));
         } catch (JSONException e) {
 			throw generateException(USMContentTypesUtilErrorCodes.CONFIRM_ERROR_NUMBER1, object,
@@ -224,7 +226,9 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         JSONObject requestBody = new JSONObject();
         try {
             requestBody.put("confirmation", response);
-            requestBody.put("confirmmessage", confirmMessage);
+            if (!confirmMessage.isEmpty()) {
+                requestBody.put("confirmmessage", confirmMessage);
+            }
             requestBody.put("mail", participantId);
             requestBody.put("type", 5);
         } catch (JSONException e) {
@@ -620,6 +624,27 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         }
     }
 
+	protected JSONArray checkInvalidCharacters(JSONObject errorObject) throws InternalUSMException {
+        try {
+            int category = errorObject.optInt(CommonConstants.CATEGORY);
+            String message = errorObject.optString(CommonConstants.ERROR);
+            String code = errorObject.optString(CommonConstants.CODE);
+            if (category == OXErrorConstants.CATEGORY_WRONG_INPUT && OXErrorConstants.APP_0071.equals(code)) {
+                LOG.debug(message);
+                JSONArray errorParams = errorObject.getJSONArray(ERROR_PARAMS);
+                if (errorParams != null) {
+                    LOG.debug(errorParams);
+                }
+                return errorParams;
+            }
+        } catch (JSONException e) {
+            throw new InternalUSMException(USMContentTypesUtilErrorCodes.OX_RESULT_ERROR_NUMBER12,
+                "OX server sent an invalid  error object " + errorObject);
+        }
+        return null;
+	}
+	
+	
     @Override
     public void readDataObject(DataObject object, BitSet requestedFields) throws USMException {
         readDataObject(object, requestedFields, new HashMap<String, String>());
