@@ -91,8 +91,9 @@ public class TableDefinition {
                     con.setAutoCommit(false);
                 if (createTable)
                     stmt.execute(SQLToolkit.createSequenceStatement(sequenceName));
-                stmt.execute(SQLToolkit.dropSequenceProcedure(sequenceName));
-                stmt.execute(SQLToolkit.createSequenceProcedure(sequenceName));
+                // do not create stored procedures anymore, they will be deleted by USMDeleteStoredProceduresUpdateTaskV2 anyway
+                //stmt.execute(SQLToolkit.dropSequenceProcedure(sequenceName));
+                //stmt.execute(SQLToolkit.createSequenceProcedure(sequenceName));
                 con.commit();
                 LOG.info("Creation of sequence " + sequenceName + " successfully performed");
             } catch (SQLException e) {
