@@ -57,6 +57,7 @@ import com.openexchange.groupware.update.UpdateTaskV2;
 import com.openexchange.groupware.update.UpdateTaskProviderService;
 import com.openexchange.usm.database.ox.update.ChangeCollationUpdateTask;
 import com.openexchange.usm.database.ox.update.USMCreatePrimaryKeyUpdateTask;
+import com.openexchange.usm.database.ox.update.USMDeleteStoredProceduresUpdateTaskV2;
 import com.openexchange.usm.database.ox.update.USMTablesUpdateTaskV2;
 import com.openexchange.usm.database.ox.update.USMUUIDTablesUpdateTaskV2;
 
@@ -82,7 +83,7 @@ public class USMUpdateTaskProvider implements UpdateTaskProviderService {
         // which would cause slow syncs
         updateTasks.add(new ChangeCollationUpdateTask(this));
         updateTasks.add(new USMCreatePrimaryKeyUpdateTask(this));
-        // TODO The next UpdateTask should include code to remove all stored procedures for sequences used throughout USM
+        updateTasks.add(new USMDeleteStoredProceduresUpdateTaskV2(this));
         return updateTasks;
     }
 
