@@ -80,8 +80,9 @@ public abstract class USMBaseUpdateTaskV2 extends UpdateTaskAdapter {
     public void perform(PerformParameters params) throws OXException {
         String taskName = getClass().getName();
         int i = taskName.lastIndexOf('.');
-        if (i >= 0)
+        if (i >= 0) {
             taskName = taskName.substring(i + 1);
+        }
         LOG.debug("Performing UpdateTask '" + taskName);
         doPerform(params);
         LOG.info("UpdateTask '" + taskName + "' successfully performed!");
@@ -115,7 +116,7 @@ public abstract class USMBaseUpdateTaskV2 extends UpdateTaskAdapter {
 
     /**
      * Check a table's existence
-     * 
+     *
      * @param tableName The table name to check
      * @param dbmd The database's meta data
      * @return <code>true</code> if table exists; otherwise <code>false</code>
@@ -125,13 +126,15 @@ public abstract class USMBaseUpdateTaskV2 extends UpdateTaskAdapter {
         ResultSet resultSet = null;
         try {
             resultSet = dbmd.getTables(null, null, tableName, TYPES);
-            if (resultSet == null) return false;
+            if (resultSet == null) {
+                return false;
+            }
             return resultSet.next();
         } finally {
             Toolkit.close(resultSet);
         }
     }
-    
+
     public static Set<String> getTableIndexes(String tableName, Connection conn) throws SQLException {
         Set<String> indexes = new HashSet<String>();
         ResultSet indexInfo = null;
@@ -139,8 +142,9 @@ public abstract class USMBaseUpdateTaskV2 extends UpdateTaskAdapter {
             indexInfo = conn.getMetaData().getIndexInfo(conn.getCatalog(), null, tableName, false, false);
             while(indexInfo.next()) {
                 String indexName = indexInfo.getString("INDEX_NAME");
-                if(indexName != null)
+                if(indexName != null) {
                     indexes.add(indexName);
+                }
             }
         } finally {
             Toolkit.close(indexInfo);
@@ -148,12 +152,10 @@ public abstract class USMBaseUpdateTaskV2 extends UpdateTaskAdapter {
         return indexes;
     }
 
-    protected void createTable(final String tablename, final String sqlCreate, final int contextId)
+    protected void createTable(final String tablename, final String sqlCreate, final Connection con)
         throws OXException {
-        Connection con = null;
         Statement stmt = null;
         try {
-            con = _provider.getDatabaseService().getForUpdateTask(contextId);
             if (!tableExists(tablename, con.getMetaData())) {
                 stmt = con.createStatement();
                 stmt.executeUpdate(sqlCreate);
@@ -162,8 +164,6 @@ public abstract class USMBaseUpdateTaskV2 extends UpdateTaskAdapter {
             throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
         } finally {
             Toolkit.close(stmt);
-            if (con != null)
-                _provider.getDatabaseService().backWritable(contextId, con);
         }
     }
 
