@@ -66,14 +66,13 @@ public class USMTablesUpdateTaskV2 extends USMBaseUpdateTaskV2 {
 
 	@Override
 	protected void doPerform(PerformParameters params) throws OXException {
-	    int contextId = params.getContextId();
-        for (int i = 0; i < TableDefinition.TABLE_NAMES.length; i++)
-            createTable(TableDefinition.TABLE_NAMES[i], TableDefinition.SQL_STATEMENTS[i], contextId);
+	    Connection con = params.getConnection();
+        for (int i = 0; i < TableDefinition.TABLE_NAMES.length; i++) {
+            createTable(TableDefinition.TABLE_NAMES[i], TableDefinition.SQL_STATEMENTS[i], con);
+        }
 
         for (int i = 0; i < TableDefinition.SEQUENCE_TABLES_NAMES.length; i++) {
-            Connection con = null;
             try {
-                con = _provider.getDatabaseService().getForUpdateTask(contextId);
                 String tablename = TableDefinition.SEQUENCE_TABLES_NAMES[i];
                 TableDefinition.generateSequence(tablename, con, true, !tableExists(tablename,
                         con.getMetaData()));
@@ -83,9 +82,6 @@ public class USMTablesUpdateTaskV2 extends USMBaseUpdateTaskV2 {
                 throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
             } catch (StorageAccessException e) {
                 throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
-            } finally {
-                if (con != null)
-                    _provider.getDatabaseService().backWritable(contextId, con);
             }
         }
 	}
