@@ -48,9 +48,9 @@
  */
 package com.openexchange.usm.database.ox.update;
 
+import java.sql.Connection;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.update.PerformParameters;
-import com.openexchange.groupware.update.Schema;
 import com.openexchange.usm.database.ox.TableDefinition;
 import com.openexchange.usm.database.ox.USMUpdateTaskProvider;
 
@@ -65,10 +65,10 @@ public class USMUUIDTablesUpdateTaskV2 extends USMBaseUpdateTaskV2 {
 
 	@Override
 	protected void doPerform(PerformParameters params) throws OXException {
-        Schema schema = params.getSchema();
-        int contextId = params.getContextId();
-        for (int i = 0; i < TABLE_NAMES.length; i++)
-            createTable(TABLE_NAMES[i], TableDefinition.UUID_SQL_STATEMENTS[i], contextId);
+        Connection con = params.getConnection();
+        for (int i = 0; i < TABLE_NAMES.length; i++) {
+            createTable(TABLE_NAMES[i], TableDefinition.UUID_SQL_STATEMENTS[i], con);
+        }
     }
 
 	@Override
