@@ -49,9 +49,11 @@
 
 package com.openexchange.usm.ox_json.impl;
 
+import java.io.BufferedReader;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.InputStreamReader;
 import java.io.UnsupportedEncodingException;
 import java.net.URLEncoder;
 import java.util.ArrayList;
@@ -90,6 +92,7 @@ import org.apache.commons.logging.LogFactory;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.java.Streams;
 import com.openexchange.usm.api.USMVersion;
 import com.openexchange.usm.api.contenttypes.resource.ResourceInputStream;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
@@ -176,7 +179,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 
     /**
      * Initializes a new {@link OXJSONAccessImpl}.
-     * 
+     *
      * @param oxJSONURL
      * @param maxConnections
      * @param connectionTimeout
@@ -198,11 +201,13 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         logout(session, false);
         try {
             OXConnectionData result = obtainConnectionData(session);
-            if (LOG.isDebugEnabled())
+            if (LOG.isDebugEnabled()) {
                 LOG.debug(session + " Logged in, session id = " + result.getSessionID());
+            }
         } catch (AuthenticationFailedException e) {
-            if (LOG.isDebugEnabled())
+            if (LOG.isDebugEnabled()) {
                 LOG.debug(session + " Authentication failed", e);
+            }
             throw e;
         } catch (OXCommunicationException e) {
             LOG.warn(session + " Error while authenticating", e);
@@ -213,8 +218,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     @Override
     public JSONObject getConfiguration(Session session, String... path) throws AuthenticationFailedException, OXCommunicationException {
         JSONObject config = readConfiguration(session, path);
-        if (LOG.isDebugEnabled())
+        if (LOG.isDebugEnabled()) {
             LOG.debug(session + " Retrieved OX ajax configuration");
+        }
         return config;
     }
 
@@ -222,8 +228,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         String accessPath = CONFIG;
         if (path.length > 0) {
             StringBuilder sb = new StringBuilder(CONFIG);
-            for (String part : path)
+            for (String part : path) {
                 sb.append(part).append('/');
+            }
             accessPath = sb.toString();
         }
         JSONResult result = doGet(accessPath, null, session, null);
@@ -235,19 +242,21 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         }
         try {
             Object object = result.getJSONObject().get(DATA);
-            if (object instanceof String)
+            if (object instanceof String) {
                 return new JSONObject().put(DATA, object);
-            else if (object instanceof JSONObject)
+            } else if (object instanceof JSONObject) {
                 return (JSONObject) object;
-            if (object instanceof JSONArray)
+            }
+            if (object instanceof JSONArray) {
                 return new JSONObject().put(DATA, object);
-            else if (object instanceof Integer)
+            } else if (object instanceof Integer) {
                 return new JSONObject().put(DATA, String.valueOf(object));
-            else
+            } else {
                 throw new OXCommunicationException(
                     OXJSONErrorCode.ACCESSIMPL_ILLEGAL_DATA_BY_OXCONFIG_RESPONSE_NUMBER_4,
                     "OX configuration response contains illegal data",
                     result.toString());
+            }
         } catch (JSONException e) {
             throw new OXCommunicationException(
                 OXJSONErrorCode.ACCESSIMPL_ILLEGAL_DATA_BY_OXCONFIG_RESPONSE_NUMBER_4,
@@ -271,20 +280,22 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         for (String header : session.getXRequestHeaders().keySet()) {
             if (CUSTOM_HOST_HEADER.equals(header) && _passClientHostHeader) {
                 method.setRequestHeader(header, session.getXRequestHeaders().get(header));
-            } else
+            } else {
                 method.setRequestHeader(header, session.getXRequestHeaders().get(header));
+            }
         }
         JSONResult result = executeMethodOnce(session, client, method);
-        if (result.getResultType() == JSONResultType.Error)
+        if (result.getResultType() == JSONResultType.Error) {
             throw new AuthenticationFailedException(
                 OXJSONErrorCode.ACCESSIMPL_AUTHENTICATION_FAILED_NUMBER_5,
                 "Authentication failed",
                 result.getJSONObject());
-        else if (result.getResultType() != JSONResultType.JSONObject)
+        } else if (result.getResultType() != JSONResultType.JSONObject) {
             throw new OXCommunicationException(
                 OXJSONErrorCode.ACCESSIMPL_INVALID_RESULT_FROM_SERVER,
                 "Server responce does not contain JSONObject",
                 result.toString());
+        }
         try {
             String sessionID = result.getJSONObject().getString("session");
             int userId = result.getJSONObject().getInt("user_id");
@@ -310,8 +321,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     }
 
     private void logout(Session session, boolean doLog) {
-        if (doLog && LOG.isDebugEnabled())
+        if (doLog && LOG.isDebugEnabled()) {
             LOG.debug(session + " Logging out");
+        }
         if (!obtainOptionalLock(session, "login?action=logout")) {
             LOG.warn("Timeout while waiting to log out session " + session);
             session.setOXConnectionData(null);
@@ -328,14 +340,16 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 
     @Override
     public void logout(OXConnectionInformation info) {
-        if (LOG.isDebugEnabled())
+        if (LOG.isDebugEnabled()) {
             LOG.debug("Logging out " + info);
+        }
         performLogout(info);
     }
 
     private void performLogout(OXConnectionInformation info) {
-        if (!(info instanceof OXConnectionData))
+        if (!(info instanceof OXConnectionData)) {
             return;
+        }
         OXConnectionData data = (OXConnectionData) info;
         GetMethod method = new GetMethod(getBaseURL() + "login?action=logout&session=" + urlEncode(data.getSessionID()));
         try {
@@ -354,8 +368,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     public JSONResult doGet(String path, String action, Session session, Map<String, String> parameters) throws AuthenticationFailedException, OXCommunicationException {
         OXConnectionData data = obtainConnectionData(session);
         String url = getBaseURL() + path;
-        if (LOG.isDebugEnabled())
+        if (LOG.isDebugEnabled()) {
             LOG.debug(session + " GET " + url);
+        }
         GetMethod method = new GetMethod(url);
         method.setQueryString(generateQueryParameters(action, data.getSessionID(), parameters));
         return executeMethodAndExtractResult(session, data, method, action, parameters);
@@ -403,8 +418,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     private JSONResult doPut(String path, String action, Session session, Map<String, String> parameters, String type, RequestEntity entity) throws AuthenticationFailedException, OXCommunicationException {
         OXConnectionData data = obtainConnectionData(session);
         String url = getBaseURL() + path;
-        if (LOG.isDebugEnabled())
+        if (LOG.isDebugEnabled()) {
             LOG.debug(session + " PUT " + url + " with " + type);
+        }
         PutMethod method = new PutMethod(url);
         method.setQueryString(generateQueryParameters(action, data.getSessionID(), parameters));
         method.setRequestEntity(entity);
@@ -460,13 +476,15 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     }
 
     private void deactivate(String message) {
-        if (_backgroundConnectionCloser != null && _backgroundConnectionCloser.isAlive())
+        if (_backgroundConnectionCloser != null && _backgroundConnectionCloser.isAlive()) {
             _backgroundConnectionCloser.interrupt();
+        }
         _backgroundConnectionCloser = null;
         _oxJSONBaseURL = null;
         _oxJSONBaseURLasString = null;
-        if (message != null)
+        if (message != null) {
             LOG.info(message);
+        }
     }
 
     private OXConnectionData obtainConnectionData(Session session) throws AuthenticationFailedException, OXCommunicationException {
@@ -487,13 +505,16 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 
     private static NameValuePair[] generateQueryParameters(String action, String sessionID, Map<String, String> params) {
         List<NameValuePair> list = new ArrayList<NameValuePair>();
-        if (action != null)
+        if (action != null) {
             list.add(new NameValuePair("action", action));
-        if (sessionID != null)
+        }
+        if (sessionID != null) {
             list.add(new NameValuePair("session", sessionID));
+        }
         if (params != null) {
-            for (Map.Entry<String, String> entry : params.entrySet())
+            for (Map.Entry<String, String> entry : params.entrySet()) {
                 list.add(new NameValuePair(entry.getKey(), entry.getValue()));
+            }
         }
         list.add(new NameValuePair("timezone", "UTC"));
         return list.toArray(new NameValuePair[list.size()]);
@@ -519,8 +540,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             JSONResult result = executeMethodOnce(session, data.getHttpClient(), method);
             // On specific error for expired/unknown session, do login and repeat
             if (OXJSONSupport.shouldPerformNewLogin(result)) {
-                if (LOG.isDebugEnabled())
+                if (LOG.isDebugEnabled()) {
                     LOG.debug(session + " Session with sessionid " + data.getSessionID() + " unknown to OX server, performing login and repeat");
+                }
                 login(session);
                 data = obtainConnectionData(session);
                 method.setQueryString(generateQueryParameters(action, data.getSessionID(), parameters));
@@ -528,15 +550,17 @@ public class OXJSONAccessImpl implements OXJSONAccess {
                 result = executeMethodOnce(session, data.getHttpClient(), method);
             }
             for (int i = 0; i < MAX_RETRY && shouldRetryRequest(result); i++) {
-                if (LOG.isDebugEnabled())
+                if (LOG.isDebugEnabled()) {
                     LOG.debug("Server returned error from category: " + OXJSONUtil.getJSONErrorCategory(result.getJSONObject()) + ". Retrying request..");
+                }
                 result = executeMethodOnce(session, data.getHttpClient(), method);
             }
-            if (shouldRetryRequest(result))
+            if (shouldRetryRequest(result)) {
                 throw new TemporaryDownOrBusyException(
                     OXJSONErrorCode.ACCESSIMPL_TOO_MANY_DOWN_OR_BUSY_RETRIES,
                     "Server/Resource is temporary down or busy.",
                     result.getJSONObject());
+            }
             return result;
         } finally {
             releaseLock(session);
@@ -548,16 +572,19 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         long startTime = collectOXStatistics ? System.currentTimeMillis() : 0L;
         try {
             int statusCode = executeMethod(client, method);
-            if (statusCode != HttpStatus.SC_OK)
+            if (statusCode != HttpStatus.SC_OK) {
                 throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_HTTP_CONNECTION_ERROR_11, statusCode);
-            JSONResult result = OXJSONSupport.parseResult(extractResponseBodyAsString(method), null);
-            if (isSynchronizationConflictError(result))
+            }
+            JSONResult result = OXJSONSupport.parseResult(extractResponseBodyAsBufferedReader(method), null);
+            if (isSynchronizationConflictError(result)) {
                 throw new ConflictingChangeException(
                     OXJSONErrorCode.ACCESSIMPL_CONFLICT_CHANGE_ON_OXACCESS_NUMBER_12,
                     "Conflicting change on OX access",
                     result.getJSONObject());
-            if (LOG.isDebugEnabled())
+            }
+            if (LOG.isDebugEnabled()) {
                 LOG.debug("RESULT: " + result);
+            }
             return result;
         } catch (HttpException e) {
             throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_HTTPEXCEPTION_OCCURED_NUMBER_13, e);
@@ -565,8 +592,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_EXECUTE_METHOD_ERROR_NUMBER_14, e);
         } finally {
             method.releaseConnection();
-            if (collectOXStatistics)
+            if (collectOXStatistics) {
                 collectOXStatistics(session, startTime);
+            }
         }
     }
 
@@ -577,7 +605,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         long accTime = getSessionProperty(session, OXJSONPropertyNames.ACCUMULATED_TIME);
         session.setCustomProperty(OXJSONPropertyNames.ACCUMULATED_TIME, Long.valueOf(accTime + duration));
     }
-    
+
     private static long getSessionProperty(Session session, String name) {
         Object o = session.getCustomProperty(name);
         return (o instanceof Long) ? ((Long) o).longValue() : 0L;
@@ -588,8 +616,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     }
 
     private static boolean shouldRetryRequest(JSONResult result) {
-        if (result.getResultType() != JSONResultType.Error)
+        if (result.getResultType() != JSONResultType.Error) {
             return false;
+        }
         if (OXJSONErrorCode.MSG_0043.equals(OXJSONUtil.getJSONErrorCode(result.getJSONObject()))) {
             return false;
         }
@@ -604,8 +633,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         boolean freeMethod = true;
         try {
             String resourceMessage = session + " GET " + _oxJSONBaseURLasString + " + " + path;
-            if (LOG.isDebugEnabled())
+            if (LOG.isDebugEnabled()) {
                 LOG.debug(resourceMessage);
+            }
             OXConnectionData connectionData = obtainConnectionData(session);
             boolean collectOXStatistics = ALWAYS_COLLECT_STATISTICS || LOG.isDebugEnabled();
             long startTime = collectOXStatistics ? System.currentTimeMillis() : 0L;
@@ -627,8 +657,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
                 method.setQueryString(generateQueryParameters(null, connectionData.getSessionID(), parameters));
             }
             int statusCode = executeMethod(connectionData.getHttpClient(), method);
-            if (statusCode != HttpStatus.SC_OK)
+            if (statusCode != HttpStatus.SC_OK) {
                 throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_INVALID_STATUSCODE_NUMBER_15, statusCode);
+            }
             Header responseHeader = method.getResponseHeader("Content-Type");
             if (responseHeader == null) {
                 throw new OXCommunicationException(
@@ -641,10 +672,11 @@ public class OXJSONAccessImpl implements OXJSONAccess {
                 freeMethod = false;
                 return ris;
             }
-            if (contentType == null || !contentType.startsWith(TEXT_HTML))
+            if (contentType == null || !contentType.startsWith(TEXT_HTML)) {
                 throw new OXCommunicationException(
                     OXJSONErrorCode.ACCESSIMPL_INVALID_CONTENT_TYPE_RECEIVED,
                     "Invalid content type in response: " + contentType);
+            }
             String httpResult = extractResponseBodyAsString(method);
             int startIndex = httpResult.indexOf("({");
             int endIndex = httpResult.lastIndexOf("})");
@@ -663,8 +695,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         } catch (IOException e) {
             throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_GETRESOURCE_ERROR_NUMBER_18, e);
         } finally {
-            if (freeMethod && method != null)
+            if (freeMethod && method != null) {
                 method.releaseConnection();
+            }
         }
     }
 
@@ -682,8 +715,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         } catch (IOException e) {
             throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_CAN_NOT_READ_RESOURCE, e);
         } finally {
-            if(data == null)
+            if(data == null) {
                 releaseLock(session);
+            }
         }
     }
 
@@ -706,6 +740,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         return storeResource(path, action, session, parameters, jsonData, imageByteData, fileContentType, STRING_PART_NAME, FILE_PART_NAME);
     }
 
+    @Override
     public JSONResult storeResourceFromStream(String path, String action, Session session, Map<String, String> parameters, JSONObject jsonData, String fileContentType, final long size, final InputStreamProvider streamProvider) throws AuthenticationFailedException, OXCommunicationException {
         return storeResourceFromStream(
             path,
@@ -720,6 +755,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             streamProvider);
     }
 
+    @Override
     public JSONResult storeResource(String path, String action, Session session, Map<String, String> parameters, JSONObject jsonData, byte[] imageByteData, String fileContentType, String jsonPartName, String filePartName) throws AuthenticationFailedException, OXCommunicationException {
         ByteArrayPartSource source = new ByteArrayPartSource(filePartName, imageByteData);
         return storeResource(path, action, session, parameters, jsonData, fileContentType, jsonPartName, filePartName, source);
@@ -755,8 +791,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             OXConnectionData connectionData = obtainConnectionData(session);
             String url = getBaseURL() + path;
 
-            if (LOG.isDebugEnabled())
+            if (LOG.isDebugEnabled()) {
                 LOG.debug(session + " POST " + url);
+            }
 
             multiPartPostMethod = new PostMethod(url);
             multiPartPostMethod.setQueryString(generateQueryParameters(action, connectionData.getSessionID(), parameters));
@@ -778,11 +815,13 @@ public class OXJSONAccessImpl implements OXJSONAccess {
                 parts.toArray(new Part[parts.size()]),
                 multiPartPostMethod.getParams()));
 
-            if(collectOXStatistics)
+            if(collectOXStatistics) {
                 startTime = System.currentTimeMillis();
+            }
             int statusCode = executeMethod(connectionData.getHttpClient(), multiPartPostMethod);
-            if (statusCode != HttpStatus.SC_OK)
+            if (statusCode != HttpStatus.SC_OK) {
                 throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_INVALID_STATUSCODE_NUMBER_19, statusCode);
+            }
             String httpResult = extractResponseBodyAsString(multiPartPostMethod);
             return checkAndExtractResult(httpResult);
         } catch (URIException e) {
@@ -792,10 +831,12 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         } catch (IOException e) {
             throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_STORE_RESOURCE_ERROR_NUMBER_22, e);
         } finally {
-            if (multiPartPostMethod != null)
+            if (multiPartPostMethod != null) {
                 multiPartPostMethod.releaseConnection();
-            if(collectOXStatistics && startTime != 0L)
+            }
+            if(collectOXStatistics && startTime != 0L) {
                 collectOXStatistics(session, startTime);
+            }
         }
     }
 
@@ -825,26 +866,52 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     }
 
     private static byte[] extractResponseBody(HttpMethod method) throws IOException {
-        ByteArrayOutputStream byteArrayStream = new ByteArrayOutputStream(RESOURCE_BUFFER_DEFAULT_SIZE);
-        InputStream inputStream = method.getResponseBodyAsStream();
+        InputStream in = null;
         try {
-            byte[] data = new byte[4096];
-            for (int count = inputStream.read(data); count > 0; count = inputStream.read(data))
-                byteArrayStream.write(data, 0, count);
-            byteArrayStream.close();
-            return byteArrayStream.toByteArray();
+            in = method.getResponseBodyAsStream();
+
+            ByteArrayOutputStream sink = Streams.newByteArrayOutputStream(2048);
+            byte[] buf = new byte[512];
+            for (int read; (read = in.read(buf, 0, buf.length)) > 0;) {
+                sink.write(buf, 0, read);
+            }
+            Streams.close(in);
+            in = null;
+            return sink.toByteArray();
         } finally {
-            inputStream.close();
+            Streams.close(in);
         }
     }
 
+    private static BufferedReader extractResponseBodyAsBufferedReader(HttpMethodBase method) throws IOException {
+        return new BufferedReader(new InputStreamReader(method.getResponseBodyAsStream(), method.getResponseCharSet()));
+    }
+
     private static String extractResponseBodyAsString(HttpMethodBase method) throws IOException {
-        return new String(extractResponseBody(method), method.getResponseCharSet());
+        InputStream in = null;
+        InputStreamReader reader = null;
+        try {
+            in = method.getResponseBodyAsStream();
+            reader = new InputStreamReader(in, method.getResponseCharSet());
+
+            StringBuilder sb = new StringBuilder(2048);
+            char[] cbuf = new char[512];
+            for (int read; (read = reader.read(cbuf, 0, cbuf.length)) > 0;) {
+                sb.append(cbuf, 0, read);
+            }
+            Streams.close(reader, in);
+            reader = null;
+            in = null;
+            return sb.toString();
+        } finally {
+            Streams.close(reader, in);
+        }
     }
 
     private int executeMethod(HttpClient client, HttpMethod method) throws HttpException, IOException {
-        if (LOG.isDebugEnabled())
+        if (LOG.isDebugEnabled()) {
             LOG.debug(method.getName() + method.getPath() + "&" + method.getQueryString());
+        }
         for (Header header : method.getRequestHeaders()) {
             LOG.debug("Header: " + header.getName() + ":" + header.getValue());
         }
@@ -869,8 +936,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             }
             redirectFromServer = location.getValue();
             URI newURI = new URI(redirectFromServer, true, method.getParams().getUriCharset());
-            if (newURI.isRelativeURI())
+            if (newURI.isRelativeURI()) {
                 newURI = new URI(method.getURI(), newURI);
+            }
             method.setURI(newURI);
         }
         LOG.error("Too many HTTP redirects accessing JSON interface of OX-Server");
@@ -889,16 +957,17 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         method.setQueryString(generateQueryParameters(action, data.getSessionID(), parameters));
 
         JSONResult result = executeMethodOnce(session, data.getHttpClient(), method);
-        if (result.getResultType() == JSONResultType.Error)
+        if (result.getResultType() == JSONResultType.Error) {
             throw new AuthenticationFailedException(
                 OXJSONErrorCode.ACCESSIMPL_AUTHENTICATION_FAILED,
                 "Authentication failed",
                 result.getJSONObject());
-        else if (result.getResultType() != JSONResultType.JSONObject)
+        } else if (result.getResultType() != JSONResultType.JSONObject) {
             throw new OXCommunicationException(
                 OXJSONErrorCode.ACCESSIMPL_INVALID_RESULT_FROM_SERVER_2,
                 "Server responce does not contain JSONObject",
                 result.toString());
+        }
         return result;
     }
 
@@ -912,8 +981,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 
     private void obtainRequiredLock(Session session, String requestInformation) throws OXCommunicationException {
         try {
-            if (tryLock(session, requestInformation))
+            if (tryLock(session, requestInformation)) {
                 return;
+            }
         } catch (InterruptedException e) {
             throw new OXCommunicationException(
                 OXJSONErrorCode.INTERRUPTED_WHILE_WAITING_FOR_ACCESS,
@@ -928,8 +998,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 
     private boolean tryLock(Session session, String requestInformation) throws InterruptedException {
         for (int i = 0; i < LOCK_TIMEOUT; i += 10) {
-            if (tryLock(session, requestInformation, 10))
+            if (tryLock(session, requestInformation, 10)) {
                 return true;
+            }
         }
         return false;
     }
@@ -948,8 +1019,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             }
         }
         boolean success = session.getOXConnectionLock().tryLock(timeout, TimeUnit.SECONDS);
-        if (success)
+        if (success) {
             setRequestInformation(session, requestInformation);
+        }
         return success;
     }
 
